@@ -1,5 +1,3 @@
-# -*- coding: utf-8 -*-
-#
 # Configuration file for the Sphinx documentation builder.
 #
 # This file only contains a selection of the most common options. For a full
@@ -19,29 +17,31 @@ sys.path.insert(0, os.path.abspath('sphinxext'))
 # -- Project information -----------------------------------------------------
 
 project = 'PyEPR'
-copyright = '2011-2020, Antonio Valentino'
+copyright = '2011-2021, Antonio Valentino'
 author = 'Antonio Valentino'
 
-def get_version(filename='../src/epr.pyx', release=False):
+def get_version(filename, strip_extra=False):
     import re
     from distutils.version import LooseVersion
 
-    s = open(filename).read()
-    mobj = re.search("^__version__ = '(?P<version>.*)'$", s, re.MULTILINE)
-    mobj.group('version')
+    with open(filename) as fd:
+        data = fd.read()
 
-    v = LooseVersion(mobj.group('version'))
+    mobj = re.search(
+        r'''^__version__\s*=\s*(?P<quote>['"])(?P<version>.*)(?P=quote)''',
+        data, re.MULTILINE)
+    version = LooseVersion(mobj.group('version'))
 
-    if release:
-        return v.vstring
+    if strip_extra:
+        return '.'.join(map(str, version.version[:3]))
     else:
-        return '.'.join(map(str, v.version[:3]))
+        return version.vstring
 
 # The short X.Y version.
-version = get_version()
+version = get_version('../src/epr.pyx', strip_extra=True)
 
 # The full version, including alpha/beta/rc tags.
-release = get_version(release=True)
+release = get_version('../src/epr.pyx', strip_extra=False)
 
 # -- General configuration ---------------------------------------------------
 
@@ -138,8 +138,7 @@ html_sidebars = {
         'searchbox.html',
         'ohloh.html',
         'pypi.html',
-        'travis-ci.html',
-        'appveyor.html',
+        'gha.html',
         'readthedocs.html',
         'codecov.html',
     ],
@@ -177,7 +176,7 @@ latex_elements = {
 # (source start file, target name, title,
 #  author, documentclass [howto, manual, or own class]).
 latex_documents = [
-    (master_doc, 'pyepr.tex', u'PyEPR Documentation',
+    (master_doc, 'pyepr.tex', 'PyEPR Documentation',
      author, 'manual'),
 ]
 
@@ -189,7 +188,7 @@ latex_domain_indices = False
 # One entry per manual page. List of tuples
 # (source start file, name, description, authors, manual section).
 man_pages = [
-    (master_doc, 'pyepr', u'PyEPR Documentation',
+    (master_doc, 'pyepr', 'PyEPR Documentation',
      [author], 1)
 ]
 
@@ -199,7 +198,7 @@ man_pages = [
 # (source start file, target name, title, author,
 #  dir menu entry, description, category)
 texinfo_documents = [
-    (master_doc, 'PyEPR', u'PyEPR Documentation',
+    (master_doc, 'PyEPR', 'PyEPR Documentation',
      author, 'PyEPR', 'One line description of project.',
      'Miscellaneous'),
 ]
